# -*- coding: utf-8 -*-

"""Make hetionet exports."""

from .cli import main

if __name__ == "__main__":
    main()
